@@ -32,13 +32,13 @@
 #include <QLabel>
 #include <QPainter>
 #include <QPushButton>
+#include <QRegularExpression>
 #include <QWidget>
 #include <cstdio>
-#include "Common.h"
-#include "DialogSettings.h"
 #include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 #include "Logger.h"
+#include "Settings.h"
 
 namespace GmicQt
 {
@@ -88,8 +88,9 @@ bool ColorParameter::addTo(QWidget * widget, int row)
   updateButtonColor();
 
   _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  setTextSelectable(_label);
   _grid->addWidget(_button, row, 1, 1, 1);
-  connect(_button, SIGNAL(clicked()), this, SLOT(onButtonPressed()));
+  connect(_button, &QPushButton::clicked, this, &ColorParameter::onButtonPressed);
   return true;
 }
 
@@ -150,18 +151,17 @@ void ColorParameter::reset()
   updateButtonColor();
 }
 
-bool ColorParameter::initFromText(const char * text, int & textLength)
+bool ColorParameter::initFromText(const QString & filterName, const char * text, int & textLength)
 {
   QList<QString> list = parseText("color", text, textLength);
   if (list.isEmpty()) {
     return false;
   }
-  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0], filterName));
 
   // color(#e9cc00) and color(#e9cc00ff)
   const QString trimmed = list[1].trimmed();
-  QRegExp colorRE("#[0-9a-fA-F]{6,8}");
-  if (colorRE.exactMatch(trimmed)) {
+  if (QRegularExpression("^#([0-9a-fA-F]{6}|[0-9a-fA-F]{8})$").match(trimmed).hasMatch()) {
     _default = QColor(trimmed.left(7));
     if (trimmed.length() == 9) {
       _alphaChannel = true;
@@ -198,7 +198,7 @@ bool ColorParameter::initFromText(const char * text, int & textLength)
 void ColorParameter::onButtonPressed()
 {
   QColor color = QColorDialog::getColor(_value, QApplication::activeWindow(), tr("Select color"),
-                                        (DialogSettings::nativeColorDialogs() ? QColorDialog::ColorDialogOptions() : QColorDialog::DontUseNativeDialog) |
+                                        (Settings::nativeColorDialogs() ? QColorDialog::ColorDialogOptions() : QColorDialog::DontUseNativeDialog) |
                                             (_alphaChannel ? QColorDialog::ShowAlphaChannel : QColorDialog::ColorDialogOptions()));
   if (color.isValid()) {
     _value = color;
